pub struct JoinRule {
room: WeakRef<Room>,
matrix_join_rule: RefCell<Option<JoinRule>>,
value: Cell<JoinRuleValue>,
can_knock: Cell<bool>,
display_name: RefCell<String>,
membership_room: BoundObject<PillSource>,
we_can_join: Cell<bool>,
anyone_can_join: Cell<bool>,
own_membership_handler: RefCell<Option<SignalHandlerId>>,
}Fields
room: WeakRef<Room>The room where this join rule apply.
matrix_join_rule: RefCell<Option<JoinRule>>The current join rule from the SDK.
value: Cell<JoinRuleValue>The value of the join rule.
can_knock: Cell<bool>Whether users can knock.
display_name: RefCell<String>The string to use to display this join rule.
This string can contain markup.
membership_room: BoundObject<PillSource>The room we need to be a member of to match this join rule, if any.
This can be a Room or a RemoteRoom.
we_can_join: Cell<bool>Whether our own user can join this room on their own.
anyone_can_join: Cell<bool>Whether anyone can join this room on their own.
own_membership_handler: RefCell<Option<SignalHandlerId>>Implementations
Sourceimpl JoinRule
impl JoinRule
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl JoinRule
impl JoinRule
Sourcepub(super) fn matrix_join_rule(&self) -> Option<MatrixJoinRule>
pub(super) fn matrix_join_rule(&self) -> Option<MatrixJoinRule>
The current join rule from the SDK.
Sourcepub(super) fn update_join_rule(&self, join_rule: Option<&MatrixJoinRule>)
pub(super) fn update_join_rule(&self, join_rule: Option<&MatrixJoinRule>)
Update the join rule.
Sourcefn update_value(&self)
fn update_value(&self)
Update the value of the join rule.
Sourcefn update_can_knock(&self)
fn update_can_knock(&self)
Update whether users can knock.
Sourcefn update_membership_room(&self)
fn update_membership_room(&self)
Set the room we need to be a member of to match this join rule.
Sourcefn update_display_name(&self)
fn update_display_name(&self)
Update the display name of the join rule.
Sourcefn update_we_can_join(&self)
fn update_we_can_join(&self)
Update whether our own user can join this room on their own.
Sourcefn we_can_join(&self) -> bool
fn we_can_join(&self) -> bool
Whether our own user can join this room on their own.
Sourcefn update_anyone_can_join(&self)
fn update_anyone_can_join(&self)
Update whether our own user can join this room on their own.